
#ifndef __LOCATOR_H__
#define __LOCATOR_H__

	#ifdef WIN32
		#pragma once
		// this is needed before any of the maya includes. Generally it is better to
		// set this within the preprocessor settings of visual C++.
		#define NT_PLUGIN
	#endif

	#include <maya/MPxLocatorNode.h>
	#include <maya/MString.h>
	#include <maya/MTypeId.h>
	#include <maya/MVector.h>
	#include <maya/MDataBlock.h>
	#include <maya/MDataHandle.h>
	#include <maya/M3dView.h>
	#include <maya/MDistance.h>
	#include <maya/MFnUnitAttribute.h>
	#include <maya/MFnNumericAttribute.h>
	#include <maya/MFnMessageAttribute.h>
	#include <maya/MFnTypedAttribute.h>
	#include <maya/MPxManipContainer.h>
	#include <maya/MPointArray.h>
	#include <math.h>

	class CustomLocator
		: public MPxLocatorNode
	{
	public:

		/// \brief	This function is used to render our custom locator node
		/// \param	view	-	the maya viewport to render the locator node in
		/// \param	DGpath	-	the DAG path of the object
		/// \param	style	-	wireframe, shadeded etc
		/// \param	status	-	is the node selected, templated etc
		///
		virtual void draw( M3dView&,
						const MDagPath&,
						M3dView::DisplayStyle,
						M3dView::DisplayStatus);

		/// \brief	this function can tell maya whether the locator node has a volume
		/// \return	true if bounded, false otherwise.
		///
		virtual bool isBounded() const;

		/// \brief	returns the bounding box of the locator node
		/// \return	the nodes bounding box
		virtual MBoundingBox boundingBox() const;

		/// \brief	this function is called by mata to return a new instance of our locator node
		/// \return	the new node
		static void *creator();

		/// \brief	this function creates a description of our node
		/// \return	The status code
		static MStatus initialize();


	// type information
	public:

		/// the unique type ID of our custom node
		static const MTypeId typeId;

		/// the unique type name of our custom node
		static const MString typeName;

	// handles to the attributes added to the node.
	private:

		/// the width & height of the yellow square of the locator
		static MObject m_Size;

		/// the height of the locator node
		static MObject m_Height;
	};

#endif





